Crate auths_jwt

Crate auths_jwt 

Shared JWT claim types for the Auths identity system.

This crate provides the data types used in Auths-issued JWTs, shared between the OIDC bridge (token issuer) and MCP server (token consumer).

Structs

ActorClaim
RFC 8693 actor claim — identifies the acting party in a delegation chain.
IdpBindingClaim
IdP binding claim embedded in the JWT when an identity is bound to an enterprise IdP.
OidcClaims
OIDC claims embedded in Auths-issued JWTs.
WitnessQuorumClaim
Witness quorum info embedded in the JWT.