Shared JWT claim types for the Auths identity system.
This crate provides the data types used in Auths-issued JWTs, shared between the OIDC bridge (token issuer) and MCP server (token consumer).
Structs
- Actor
Claim - RFC 8693 actor claim — identifies the acting party in a delegation chain.
- IdpBinding
Claim - IdP binding claim embedded in the JWT when an identity is bound to an enterprise IdP.
- Oidc
Claims - OIDC claims embedded in Auths-issued JWTs.
- Witness
Quorum Claim - Witness quorum info embedded in the JWT.